@@ -60,7 +60,7 @@ setMethod("qr", signature(x = "dgCMatrix"),
 	  function(x, tol = 1e-07, LAPACK = FALSE)
 	  .Call(dgCMatrix_QR, x, TRUE))
 setMethod("qr", signature(x = "sparseMatrix"),
-	  function(x, tol, ...)
+	  function(x, ...)
 	  qr(as(as(x, "CsparseMatrix"), "dsparseMatrix"), ...))
 
 setMethod("lu", signature(x = "dgCMatrix"),
